@@ -321,7 +321,7 @@
         stop("Correlation rho must be between -1 and 1")
     }
     if(!is.null(psi) & is.null(power)){
-      if(is.null(N))
+      if(is.null(N) & is.null(DesMat$N))
         stop("If the standard deviation `psi` is not null, N is needed.")
       if(is.matrix(N)){
         N <- N[,1]
@@ -358,9 +358,10 @@
                                   timeAdjust = timeAdjust,
                                   period     = period,
                                   incomplete = incomplete,
-                                  N          = if(INDIV_LVL) N,
+                                  N          = N,
                                   INDIV_LVL  = INDIV_LVL )
-  }else{
+  }
+  else{
     if(inherits(DesMat, "DesMat")) {
       if(!all(sapply(list(Cl, timepoints ,trtDelay,period,incomplete),is.null)))      ## timeAdjust defaults to factor (!)
         warning("If input to argument DesMat inherits class `DesMat`, \n",
@@ -371,7 +372,8 @@
                                  timeAdjust = timeAdjust,
                                  period     = period,
                                  incomplete = incomplete,
-                                 N          = if(INDIV_LVL) N,
+                                 # N          = if(INDIV_LVL) N,
+                                 N          = N,
                                  INDIV_LVL  = INDIV_LVL)
       if(!all(sapply(list(Cl, timepoints, trtDelay), is.null)))
         warning("If input to argument DesMat is of class `matrix`, \n",
@@ -390,7 +392,8 @@
   ## default for INFO_CONTENT ####
   if(is.null(INFO_CONTENT)){
     INFO_CONTENT <- ifelse(length(DesMat$trtMat)<=2500 & sumCl>2 &
-                           verbose>0 & !INDIV_LVL,                   TRUE,FALSE)
+                           verbose>0 & !INDIV_LVL,
+                           TRUE,FALSE)
   }else if(INFO_CONTENT & sumCl<=2) {
     INFO_CONTENT <- FALSE
     warning("Information Content not (yet) implemented for only two clusters.",
@@ -449,29 +452,30 @@
   if(!is.null(power)){
     if(power<0 | power>1) stop("power needs to be between 0 and 1.")
     N_opt <- tryCatch(ceiling(
-              uniroot(function(N){power - compute_glsPower(DesMat    = DesMat,
-                                                           EffSize   = EffSize,
-                                                           sigma     = sigma,
-                                                           tau       = tau,
-                                                           eta       = eta,
-                                                           AR        = AR,
-                                                           rho       = rho,
-                                                           gamma     = gamma,
-                                                           psi       = psi,
-                                                           N         = N,
-                                                           dfAdjust  = dfAdjust,
-                                                           sig.level = sig.level,
-                                                           CovMat    = CovMat,
-                                                           INDIV_LVL = INDIV_LVL,
-                                                           INFO_CONTENT = FALSE,
-                                                           verbose   = 0)},
+              uniroot(function(N){
+                DesMat$N <- N
+                power - compute_glsPower(DesMat    = DesMat,
+                                         EffSize   = EffSize,
+                                         sigma     = sigma,
+                                         tau       = tau,
+                                         eta       = eta,
+                                         AR        = AR,
+                                         rho       = rho,
+                                         gamma     = gamma,
+                                         psi       = psi,
+                                         dfAdjust  = dfAdjust,
+                                         sig.level = sig.level,
+                                         CovMat    = CovMat,
+                                         INDIV_LVL = INDIV_LVL,
+                                         INFO_CONTENT = FALSE,
+                                           verbose   = 0)},
                 interval=N_range)$root),
               error=function(cond){
                 message(paste0("Maximal N yields power below ",power,
                                ". Increase argument N_range."))
                 return(N_range[2])
               })
-    N <- N_opt
+    DesMat$N <- N_opt
   }
   ## calculate Power #####
   out <- compute_glsPower(DesMat    = DesMat,
@@ -483,7 +487,6 @@
                           rho       = rho,
                           gamma     = gamma,
                           psi       = psi,
-                          N         = N,
                           dfAdjust  = dfAdjust,
                           sig.level = sig.level,
                           CovMat    = CovMat,
@@ -537,7 +540,6 @@ compute_glsPower <- function(DesMat,
                              rho        = NULL,
                              gamma      = NULL,
                              psi        = NULL,
-                             N          = NULL,
                              CovMat     = NULL,
                              dfAdjust   = "none",
                              sig.level  = .05,
@@ -562,7 +564,7 @@ compute_glsPower <- function(DesMat,
                                  gamma      = gamma,
                                  psi        = psi,
                                  trtMat     = trtMat,
-                                 N          = N,
+                                 N          = DesMat$N,
                                  INDIV_LVL  = INDIV_LVL)
 
   ## matrices for power calculation #####
@@ -643,17 +645,13 @@ compute_glsPower <- function(DesMat,
     df <- Inf }
 
   Pwr <- tTestPwr(d=EffSize, se=sqrt(Var[1,1]), df=df, sig.level=sig.level)
+
+  ## create output ####
   if(verbose==0){
     out <- Pwr
   } else {
     out <- list(power  =Pwr,
-                Params =list(Cl         = DesMat$Cl,
-                             timeAdjust = DesMat$timeAdjust,
-                             timepoints = DesMat$timepoints,
-                             designtype = DesMat$dsntype,
-                             trtDelay   = DesMat$trtDelay,
-                             N          = N,
-                             sigma      = sigma,
+                Params =list(sigma      = sigma,
                              tau        = tau,
                              eta        = eta,
                              AR         = AR,
@@ -673,8 +671,8 @@ compute_glsPower <- function(DesMat,
                   list(DesignMatrix     = DesMat,
                        CovarianceMatrix = CovMat,
                        VarianceMatrix   = Var))
-  return(out)
   }
+  return(out)
 }
 
 #' @title Print an object of class `glsPower`
